@@ -37,7 +37,8 @@ extern "C" {
 #define MISC_CREATE_MENU_RADIO     7
 #define MISC_CREATE_MENU_TERMINAL  0
 #define MISC_CREATE_MENU_ELLIPSIS  8
-#define MISC_CREATE_MENU_DISABLE   16
+#define MISC_CREATE_MENU_NOIMAGE   16
+#define MISC_CREATE_MENU_DISABLE   32
 #define MISC_CREATE_MENU_MASK      7
 
 typedef struct _MiscCreateMenuEntry
@@ -100,6 +101,29 @@ misc_find_toolbar (MiscCreateToolbarEntry *entries,
                    const gchar            *path);
 
 
+/******************************************************************************
+*                                                                             *
+* ja:特定ファイル関数群                                                       *
+*                                                                             *
+******************************************************************************/
+/*  ja:ユーザ設定ファイルを取得する
+    group,グループ
+     name,アプリケーション名
+     file,ファイル名
+      RET,ユーザ設定ファイル                                                */
+const gchar *
+misc_spec_config (const gchar *group,
+                  const gchar *name,
+                  const gchar *file);
+
+
+/*  ja:ロケールのディレクトリを取得する
+    prgname,プログラム
+        RET,ロケールのディレクトリ                                          */
+const gchar *
+misc_spec_locale (const gchar *prgname);
+
+
 /******************************************************************************
 *                                                                             *
 * ja:低レベル関数群                                                           *
