@@ -1,6 +1,6 @@
 /*
     Profile
-    copyright (c) 1998-2005 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2006 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -47,6 +47,32 @@ struct _Profile
 * ja:初期化ファイル関数群(内部)                                               *
 *                                                                             *
 ******************************************************************************/
+/*  ja:リストをテキスト化する
+    profile_list,リスト
+             RET,テキストリスト                                             */
+static gchar *
+profile_list_to_text (ProfileList *profile_list)
+{
+  gchar *text = NULL;
+  ProfileList *p;
+
+  for (p = profile_list; p; p = p->next)
+    if (text)
+      {
+        gchar *tmp;
+
+        tmp = text;
+        text = g_strconcat (text, "\n", p->data, NULL);
+        g_free (tmp);
+      }
+    else
+      {
+        text = p->data ? g_strdup (p->data) : g_strdup ("");
+      }
+  return text;
+}
+
+
 /*  ja:テキストをリスト化する
     text,テキスト
      RET,リスト                                                             */
@@ -68,8 +94,9 @@ profile_list_from_text (const gchar *text)
       p = q;
     }
   g_strfreev (buf);
-  while (p->prev)
-    p = p->prev;
+  if (p)
+    while (p->prev)
+      p = p->prev;
   r = p;
   /* ja:リストを整理する */
   while (p)
@@ -127,7 +154,7 @@ static ProfileList *
 profile_list_from_file (const gchar *file)
 {
   gchar *data;
-  gsize length;
+  gssize length;
   ProfileList *p = NULL;
 
   data = fileio_load (file, &length);
@@ -238,23 +265,19 @@ profile_open (const gchar *file)
 gboolean
 profile_close (Profile *profile)
 {
-  FileIO *fio;
-  ProfileList *p;
-
   if (!profile)
     return TRUE;
-  if (profile->edit && (fio = fileio_open (profile->file,
-                                        FILEIO_ACCESS_WRITE, FILEIO_SHARE_READ,
-                                        FILEIO_MODE_CREATE_ALWAYS)))
+  if (profile->edit)
     {
       /* ja:変更があったとき */
-      for (p = profile->list; p; p = p->next)
+      gchar *text;
+
+      text = profile_list_to_text (profile->list);
+      if (text)
         {
-          if (p->data)
-            fileio_puts (p->data, fio);
-          fileio_putc ('\n', fio);
+          fileio_save (profile->file, text, g_strlen (text) * sizeof (gchar));
+          g_free (text);
         }
-      fileio_close (fio);
     }
   profile_list_free (profile->list);
   profile_list_free (profile->sublist);
@@ -322,14 +345,14 @@ profile_get_size (Profile     *profile,
   switch (type)
     {
       case PROFILE_VALUE_TYPE_BOOL:
-        return g_strcasecmp (p->value, "true") == 0
-                || g_strcasecmp (p->value, "false") == 0
-                || g_strcasecmp (p->value, "yes") == 0
-                || g_strcasecmp (p->value, "no") == 0
-                || g_strcasecmp (p->value, "on") == 0
-                || g_strcasecmp (p->value, "off") == 0
-                || g_strcasecmp (p->value, "ok") == 0
-                || g_strcasecmp (p->value, "cancel") == 0
+        return g_ascii_strcasecmp (p->value, "true") == 0
+                || g_ascii_strcasecmp (p->value, "false") == 0
+                || g_ascii_strcasecmp (p->value, "yes") == 0
+                || g_ascii_strcasecmp (p->value, "no") == 0
+                || g_ascii_strcasecmp (p->value, "on") == 0
+                || g_ascii_strcasecmp (p->value, "off") == 0
+                || g_ascii_strcasecmp (p->value, "ok") == 0
+                || g_ascii_strcasecmp (p->value, "cancel") == 0
                 ? sizeof (gboolean) : 0;
       case PROFILE_VALUE_TYPE_INT:
         return sizeof (gint);
@@ -363,7 +386,7 @@ profile_get_value (Profile     *profile,
                    const guint  type)
 {
   guint8 *array;
-  gint n;
+  gsize n;
   ProfileList *p;
 
   if (!profile || !section || !key || !value)
@@ -384,15 +407,15 @@ profile_get_value (Profile     *profile,
       case PROFILE_VALUE_TYPE_BOOL:
         if (size < sizeof (gboolean))
           return FALSE;
-        if (g_strcasecmp (p->value, "true") == 0
-            || g_strcasecmp (p->value, "yes") == 0
-            || g_strcasecmp (p->value, "on") == 0
-            || g_strcasecmp (p->value, "ok") == 0)
+        if (g_ascii_strcasecmp (p->value, "true") == 0
+            || g_ascii_strcasecmp (p->value, "yes") == 0
+            || g_ascii_strcasecmp (p->value, "on") == 0
+            || g_ascii_strcasecmp (p->value, "ok") == 0)
           *((gboolean *)value) = TRUE;
-        else if (g_strcmp (p->value, "false") == 0
-            || g_strcasecmp (p->value, "no") == 0
-            || g_strcasecmp (p->value, "off") == 0
-            || g_strcasecmp (p->value, "cancel") == 0)
+        else if (g_ascii_strcasecmp (p->value, "false") == 0
+            || g_ascii_strcasecmp (p->value, "no") == 0
+            || g_ascii_strcasecmp (p->value, "off") == 0
+            || g_ascii_strcasecmp (p->value, "cancel") == 0)
           *((gboolean *)value) = FALSE;
         else
           return FALSE;
@@ -742,25 +765,11 @@ g_key_file_to_data (GKeyFile  *key_file,
                     gsize     *length,
                     GError   **error)
 {
-  gchar *data = NULL;
+  gchar *data;
 
   if (error)
     *error = NULL;
-  if (key_file)
-    {
-      ProfileList *p;
-
-      for (p = key_file->list; p; p = p->next)
-        {
-          gchar *tmp;
-
-          tmp = data;
-          data = data ? p->data ? g_strconcat (data, p->data, "\n", NULL)
-                                : g_strconcat (data,          "\n", NULL)
-                                : g_strconcat (      p->data, "\n", NULL);
-          g_free (tmp);
-        }
-    }
+  data = key_file ? profile_list_to_text (key_file->list) : NULL;
   if (data && length)
     *length = g_strlen (data);
   return data;
@@ -780,7 +789,7 @@ g_key_file_get_groups (GKeyFile *key_file,
       guint i, leng;
 
       leng = g_list_length (glist);
-      str = g_malloc (leng * sizeof (gchar *));
+      str = g_malloc ((leng + 1) * sizeof (gchar *));
       for (i = 0; i < leng; i++)
         str[i] = g_strdup (g_list_nth_data (glist, i));
       str[i] = NULL;
@@ -809,7 +818,7 @@ g_key_file_get_keys (GKeyFile     *key_file,
       guint i, leng;
 
       leng = g_list_length (glist);
-      str = g_malloc (leng * sizeof (gchar *));
+      str = g_malloc ((leng + 1) * sizeof (gchar *));
       for (i = 0; i < leng; i++)
         str[i] = g_strdup (g_list_nth_data (glist, i));
       str[i] = NULL;
