@@ -217,7 +217,7 @@ main (int   argc,
       second = g_key_file_get_boolean (key_file, "pref", "second", NULL);
       def_width = g_key_file_get_integer (key_file, "pref", "width", NULL);
       def_height = g_key_file_get_integer (key_file, "pref", "height", NULL);
-      n_pos = g_key_file_get_integer (key_file, "pref", "n_pos", NULL);
+      n_pos = g_key_file_get_integer (key_file, "pref", "npos", NULL);
       def_hold = g_key_file_get_boolean (key_file, "mmaid", "def_hold", NULL);
       def_gnum = g_key_file_get_integer (key_file, "mmaid", "def_gnum", NULL);
       playlist = g_key_file_get_integer (key_file, "mmaid", "playlist", NULL);
@@ -560,7 +560,7 @@ MMAID_COPYRIGHT_NOTICE"\n"
       g_key_file_set_boolean (key_file, "pref", "second", second);
       g_key_file_set_integer (key_file, "pref", "width", def_width);
       g_key_file_set_integer (key_file, "pref", "height", def_height);
-      g_key_file_set_integer (key_file, "pref", "n_pos", n_pos);
+      g_key_file_set_integer (key_file, "pref", "npos", n_pos);
       g_key_file_set_boolean (key_file, "mmaid", "def_hold", def_hold);
       g_key_file_set_integer (key_file, "mmaid", "def_gnum", def_gnum);
       g_key_file_set_integer (key_file, "mmaid", "playlist", playlist);
